@@ -1,6 +1,8 @@
 #!/usr/bin/perl
 
 package Devel::Events::Handler::Callback;
+# ABSTRACT: An event handler that delegates to code references.
+our $VERSION = '0.09';
 use Moose;
 
 with qw/Devel::Events::Handler/;
@@ -30,10 +32,16 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Devel::Events::Handler::Callback - An event handler that delegates to code references.
 
+=head1 VERSION
+
+version 0.09
+
 =head1 SYNOPSIS
 
 	use Devel::Events::Handler::Callback;
@@ -77,6 +85,20 @@ Delegates to C<callback>.
 
 =back
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Devel-Events>
+(or L<bug-Devel-Events@rt.cpan.org|mailto:bug-Devel-Events@rt.cpan.org>).
+
+=head1 AUTHOR
+
+יובל קוג'מן (Yuval Kogman) <nothingmuch@woobling.org>
+
+=head1 COPYRIGHT AND LICENCE
+
+This software is copyright (c) 2007 by יובל קוג'מן (Yuval Kogman).
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
-
-
