@@ -1,6 +1,8 @@
 #!/usr/bin/perl
 
 package Devel::Events::Match;
+# ABSTRACT: Event matching, splicing and dicing.
+our $VERSION = '0.09';
 use Moose;
 
 use Carp qw/croak/;
@@ -191,10 +193,16 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Devel::Events::Match - Event matching, splicing and dicing.
 
+=head1 VERSION
+
+version 0.09
+
 =head1 SYNOPSIS
 
 	use Devel::Events::Match;
@@ -213,6 +221,8 @@ access into the event log.
 
 =head1 METHODS
 
+=over 4
+
 =item compile_cond
 
 Used to compile condition values into code references.
@@ -272,5 +282,22 @@ The first chunk contains all the events up to the first matching one.
 
 Require the C<match> and C<events> parameters.
 
-=cut
+=back
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Devel-Events>
+(or L<bug-Devel-Events@rt.cpan.org|mailto:bug-Devel-Events@rt.cpan.org>).
+
+=head1 AUTHOR
+
+יובל קוג'מן (Yuval Kogman) <nothingmuch@woobling.org>
+
+=head1 COPYRIGHT AND LICENCE
+
+This software is copyright (c) 2007 by יובל קוג'מן (Yuval Kogman).
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
